@@ -2,7 +2,15 @@
 
 """ notifo.py - python wrapper for notifo.com """
 
-import json
+try:
+  import json
+except ImportError:
+  try:
+    import simplejson as json
+  except ImportError:
+    # For Google AppEngine
+    from django.utils import simplejson as json
+
 import urllib
 import urllib2
 from base64 import encodestring
@@ -70,7 +78,10 @@ class Notifo:
             request.add_header("Authorization", "Basic %s" % auth)
         try:
             response = urllib2.urlopen(request)
-        except IOError: # no connection
-            return None
+        except IOError, e: # no connection
+            return {"status" : "error",
+                    "response_code" : e.code,
+                    "response_message" : e.msg
+                   }
         return json.loads(response.read())
 
